function varargout = kompletni_rozklad(varargin)
% KOMPLETNI_ROZKLAD M-file for kompletni_rozklad.fig
%      KOMPLETNI_ROZKLAD, by itself, creates a new KOMPLETNI_ROZKLAD or raises the existing
%      singleton*.
%
%      H = KOMPLETNI_ROZKLAD returns the handle to a new KOMPLETNI_ROZKLAD or the handle to
%      the existing singleton*.
%
%      KOMPLETNI_ROZKLAD('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in KOMPLETNI_ROZKLAD.M with the given input arguments.
%
%      KOMPLETNI_ROZKLAD('Property','Value',...) creates a new KOMPLETNI_ROZKLAD or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before kompletni_rozklad_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to kompletni_rozklad_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help kompletni_rozklad

% Last Modified by GUIDE v2.5 24-Jan-2009 16:00:36

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @kompletni_rozklad_OpeningFcn, ...
                   'gui_OutputFcn',  @kompletni_rozklad_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before kompletni_rozklad is made visible.
function kompletni_rozklad_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to kompletni_rozklad (see VARARGIN)

% Choose default command line output for kompletni_rozklad
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes kompletni_rozklad wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = kompletni_rozklad_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;
